GridEntity

Struct GridEntity 

pub struct GridEntity { /* private fields */ }
Describes an entity that has been placed on the grid.

Implementations

Source

impl GridEntity

pub fn new( center: Vec2, rotation: GridRotation, entry: PlacementConfigEntry, ) -> Self

Creates a new GridEntity with the given center position, rotation, and placement configuration entry.

Arguments
  • center - The center position of the entity in world coordinates. Note that this is not necessarily the center of the footprint, but the position used to place the entity on the grid. It will be adjusted to the nearest grid tile.
  • rotation - The rotation of the entity on the grid, in 90 degree increments. This will affect the footprint of the entity.
  • entry - The placement configuration entry that describes the entity, including its extent and anchors.
pub fn center(&self) -> Vec2

Get the center position of this entity in world coordinates.

pub fn rotation(&self) -> GridRotation

Get the rotation of this entity on the grid.

pub fn bbox(&self) -> (Vec2, Vec2)

Gets the bounding box of this entity in world coordinates (bottom left, top right).

pub fn footprint(&self) -> &Vec<GridTilePos>

Gets the list of grid tiles that are occupied by this entity footprint.

pub fn entry(&self) -> &PlacementConfigEntry

Gets a reference to the placement configuration entry that describes this entity.